fmt_component_v3

Function fmt_component_v3 

fn fmt_component_v3<V>(
    output: &mut (impl Write + ?Sized),
    value: &V,
    state: &mut <V as ComponentProvider>::State,
    component: &Component,
) -> Result<usize, Format>
Available on crate feature formatting only.
Format the provided component into the designated output. An Err will be returned if the component requires information that it does not provide or if the value cannot be output to the stream.